==> ejc-salary-impl-3.0.0-20240920.090720-5-sources.jar: com/ejianc/business/salary/bean/RosterEntity.java <==
package com.ejianc.business.salary.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.salary.bean.RosterJobEntity;
import com.ejianc.business.salary.bean.RosterSocialSecurityEntity;
import com.ejianc.business.salary.bean.RosterAccumulationFundEntity;
import com.ejianc.business.salary.bean.RosterAttendanceEntity;
import com.ejianc.business.salary.bean.RosterTransferEntity;
import com.ejianc.business.salary.bean.RosterCertificateEntity;
/**
 * 人员花名册
 * 
 * @author generator
 * 
 */
 @TableName("ejc_salary_roster")
public class RosterEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="employee_code")
    private String employeeCode; // 员工编码
    @TableField(value="user_id")
    private Long userId; // 员工id
    @TableField(value="user_code")
    private String userCode; // 员工编号
    @TableField(value="user_name")
    private String userName; // 人员名称
    @TableField(value="org_id")
    private Long orgId; // 单位id
    @TableField(value="org_code")
    private String orgCode; // 单位编码
    @TableField(value="org_name")
    private String orgName; // 单位名称
    @TableField(value="department_id")
    private Long departmentId; // 部门id
    @TableField(value="department_code")
    private String departmentCode; // 部门编码
    @TableField(value="department_name")
    private String departmentName; // 部门名称
    @TableField(value="post_id")
    private Long postId; // 岗位id
    @TableField(value="post_name")
    private String postName; // 岗位
    @TableField(value="job_level_name")
    private String jobLevelName; // 岗级
    @TableField(value="id_card")
    private String idCard; // 身份证号
    @TableField(value="sex_name")
    private String sexName; // 性别
    @TableField(value="user_type_name")
    private String userTypeName; // 人员类别
    @TableField(value="mobile_phone")
    private String mobilePhone; // 手机号码
    @TableField(value="residency_type_name")
    private String residencyTypeName; // 派驻类别
    @TableField(value="education_name")
    private String educationName; // 最高学历
    @TableField(value="title_name")
    private String titleName; // 最高职称
    @TableField(value="social_department_code")
    private String socialDepartmentCode; // 社保缴纳单位编号
    @TableField(value="social_department_name")
    private String socialDepartmentName; // 社保缴纳单位
    @TableField(value="work_year")
    private String workYear; // 司龄
    @TableField(value="source_type")
    private String sourceType; // 人员库
    @TableField(value="bank_name")
    private String bankName; // 开户行
    @TableField(value="bank_account")
    private String bankAccount; // 银行账户
    @TableField(value="bank_address")
    private String bankAddress; // 银行地址
    @TableField(value="sync_day")
    private Long syncDay; // 同步日期
    @TableField(value="hr_state")
    private Integer hrState; // 人力状态（1：正常，2：删除）
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="rosterJobService")
    private List<RosterJobEntity> rosterJobList = new ArrayList<>(); // 人员花名册-兼职库
    @TableField(exist=false)
    @SubEntity(serviceName="rosterSocialSecurityService")
    private List<RosterSocialSecurityEntity> rosterSocialSecurityList = new ArrayList<>(); // 人员花名册-社保
    @TableField(exist=false)
    @SubEntity(serviceName="rosterAccumulationFundService")
    private List<RosterAccumulationFundEntity> rosterAccumulationFundList = new ArrayList<>(); // 人员花名册-公积金
    @TableField(exist=false)
    @SubEntity(serviceName="rosterAttendanceService")
    private List<RosterAttendanceEntity> rosterAttendanceList = new ArrayList<>(); // 人员花名册-出勤
    @TableField(exist=false)
    @SubEntity(serviceName="rosterTransferService")
    private List<RosterTransferEntity> rosterTransferList = new ArrayList<>(); // 人员花名册-异动
    @TableField(exist=false)
    @SubEntity(serviceName="rosterCertificateService")
    private List<RosterCertificateEntity> rosterCertificateList = new ArrayList<>(); // 人员花名册-证书
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentCode() {
        return departmentCode;
    }

    public void setDepartmentCode(String departmentCode) {
        this.departmentCode = departmentCode;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Long getPostId() {
        return postId;
    }

    public void setPostId(Long postId) {
        this.postId = postId;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public String getJobLevelName() {
        return jobLevelName;
    }

    public void setJobLevelName(String jobLevelName) {
        this.jobLevelName = jobLevelName;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getSexName() {
        return sexName;
    }

    public void setSexName(String sexName) {
        this.sexName = sexName;
    }
    public String getUserTypeName() {
        return userTypeName;
    }

    public void setUserTypeName(String userTypeName) {
        this.userTypeName = userTypeName;
    }
    public String getMobilePhone() {
        return mobilePhone;
    }

    public void setMobilePhone(String mobilePhone) {
        this.mobilePhone = mobilePhone;
    }
    public String getResidencyTypeName() {
        return residencyTypeName;
    }

    public void setResidencyTypeName(String residencyTypeName) {
        this.residencyTypeName = residencyTypeName;
    }
    public String getEducationName() {
        return educationName;
    }

    public void setEducationName(String educationName) {
        this.educationName = educationName;
    }
    public String getTitleName() {
        return titleName;
    }

    public void setTitleName(String titleName) {
        this.titleName = titleName;
    }
    public String getSocialDepartmentCode() {
        return socialDepartmentCode;
    }

    public void setSocialDepartmentCode(String socialDepartmentCode) {
        this.socialDepartmentCode = socialDepartmentCode;
    }
    public String getSocialDepartmentName() {
        return socialDepartmentName;
    }

    public void setSocialDepartmentName(String socialDepartmentName) {
        this.socialDepartmentName = socialDepartmentName;
    }
    public String getWorkYear() {
        return workYear;
    }

    public void setWorkYear(String workYear) {
        this.workYear = workYear;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public String getBankAddress() {
        return bankAddress;
    }

    public void setBankAddress(String bankAddress) {
        this.bankAddress = bankAddress;
    }
    public Long getSyncDay() {
        return syncDay;
    }

    public void setSyncDay(Long syncDay) {
        this.syncDay = syncDay;
    }
    public Integer getHrState() {
        return hrState;
    }

    public void setHrState(Integer hrState) {
        this.hrState = hrState;
    }
    

    public List<RosterJobEntity> getRosterJobList() {
        return rosterJobList;
    }

    public void setRosterJobList(List<RosterJobEntity> rosterJobList) {
        this.rosterJobList = rosterJobList;
    }

    public List<RosterSocialSecurityEntity> getRosterSocialSecurityList() {
        return rosterSocialSecurityList;
    }

    public void setRosterSocialSecurityList(List<RosterSocialSecurityEntity> rosterSocialSecurityList) {
        this.rosterSocialSecurityList = rosterSocialSecurityList;
    }

    public List<RosterAccumulationFundEntity> getRosterAccumulationFundList() {
        return rosterAccumulationFundList;
    }

    public void setRosterAccumulationFundList(List<RosterAccumulationFundEntity> rosterAccumulationFundList) {
        this.rosterAccumulationFundList = rosterAccumulationFundList;
    }

    public List<RosterAttendanceEntity> getRosterAttendanceList() {
        return rosterAttendanceList;
    }

    public void setRosterAttendanceList(List<RosterAttendanceEntity> rosterAttendanceList) {
        this.rosterAttendanceList = rosterAttendanceList;
    }

    public List<RosterTransferEntity> getRosterTransferList() {
        return rosterTransferList;
    }

    public void setRosterTransferList(List<RosterTransferEntity> rosterTransferList) {
        this.rosterTransferList = rosterTransferList;
    }

    public List<RosterCertificateEntity> getRosterCertificateList() {
        return rosterCertificateList;
    }

    public void setRosterCertificateList(List<RosterCertificateEntity> rosterCertificateList) {
        this.rosterCertificateList = rosterCertificateList;
    }
}

==> ejc-salary-impl-3.0.0-20241008.071957-10-sources.jar: com/ejianc/business/salary/bean/RosterEntity.java <==
package com.ejianc.business.salary.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.salary.bean.RosterJobEntity;
import com.ejianc.business.salary.bean.RosterSocialSecurityEntity;
import com.ejianc.business.salary.bean.RosterAccumulationFundEntity;
import com.ejianc.business.salary.bean.RosterAttendanceEntity;
import com.ejianc.business.salary.bean.RosterTransferEntity;
import com.ejianc.business.salary.bean.RosterCertificateEntity;
/**
 * 人员花名册
 * 
 * @author generator
 * 
 */
 @TableName("ejc_salary_roster")
public class RosterEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="employee_code")
    private String employeeCode; // 员工编码
    @TableField(value="user_id")
    private Long userId; // 员工id
    @TableField(value="user_code")
    private String userCode; // 员工编号
    @TableField(value="user_name")
    private String userName; // 人员名称
    @TableField(value="org_id")
    private Long orgId; // 单位id
    @TableField(value="org_code")
    private String orgCode; // 单位编码
    @TableField(value="org_name")
    private String orgName; // 单位名称
    @TableField(value="department_id")
    private Long departmentId; // 部门id
    @TableField(value="department_code")
    private String departmentCode; // 部门编码
    @TableField(value="department_name")
    private String departmentName; // 部门名称
    @TableField(value="post_id")
    private Long postId; // 岗位id
    @TableField(value="post_name")
    private String postName; // 岗位
    @TableField(value="job_level_name")
    private String jobLevelName; // 岗级
    @TableField(value="id_card")
    private String idCard; // 身份证号
    @TableField(value="sex_name")
    private String sexName; // 性别
    @TableField(value="user_type_name")
    private String userTypeName; // 人员类别
    @TableField(value="mobile_phone")
    private String mobilePhone; // 手机号码
    @TableField(value="residency_type_name")
    private String residencyTypeName; // 派驻类别
    @TableField(value="education_name")
    private String educationName; // 最高学历
    @TableField(value="title_name")
    private String titleName; // 最高职称
    @TableField(value="social_department_code")
    private String socialDepartmentCode; // 社保缴纳单位编号
    @TableField(value="social_department_name")
    private String socialDepartmentName; // 社保缴纳单位
    @TableField(value="work_year")
    private String workYear; // 司龄
    @TableField(value="source_type")
    private String sourceType; // 人员库
    @TableField(value="bank_name")
    private String bankName; // 开户行
    @TableField(value="bank_account")
    private String bankAccount; // 银行账户
    @TableField(value="bank_address")
    private String bankAddress; // 银行地址
    @TableField(value="sync_day")
    private Long syncDay; // 同步日期
    @TableField(value="hr_state")
    private Integer hrState; // 人力状态（1：正常，2：删除）
    
    
    @TableField(exist=false)
    private List<RosterJobEntity> rosterJobList = new ArrayList<>(); // 人员花名册-兼职库
    @TableField(exist=false)
    private List<RosterSocialSecurityEntity> rosterSocialSecurityList = new ArrayList<>(); // 人员花名册-社保
    @TableField(exist=false)
    private List<RosterAccumulationFundEntity> rosterAccumulationFundList = new ArrayList<>(); // 人员花名册-公积金
    @TableField(exist=false)
    private List<RosterAttendanceEntity> rosterAttendanceList = new ArrayList<>(); // 人员花名册-出勤
    @TableField(exist=false)
    private List<RosterTransferEntity> rosterTransferList = new ArrayList<>(); // 人员花名册-异动
    @TableField(exist=false)
    private List<RosterCertificateEntity> rosterCertificateList = new ArrayList<>(); // 人员花名册-证书


    @TableField(value="bank_id")
    private Long bankId; // 开户行id
    @TableField(value="bank_code")
    private String bankCode; // 开户行code


    public String getBankCode() {
        return bankCode;
    }

    public void setBankCode(String bankCode) {
        this.bankCode = bankCode;
    }

    public Long getBankId() {
        return bankId;
    }

    public void setBankId(Long bankId) {
        this.bankId = bankId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentCode() {
        return departmentCode;
    }

    public void setDepartmentCode(String departmentCode) {
        this.departmentCode = departmentCode;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Long getPostId() {
        return postId;
    }

    public void setPostId(Long postId) {
        this.postId = postId;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public String getJobLevelName() {
        return jobLevelName;
    }

    public void setJobLevelName(String jobLevelName) {
        this.jobLevelName = jobLevelName;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getSexName() {
        return sexName;
    }

    public void setSexName(String sexName) {
        this.sexName = sexName;
    }
    public String getUserTypeName() {
        return userTypeName;
    }

    public void setUserTypeName(String userTypeName) {
        this.userTypeName = userTypeName;
    }
    public String getMobilePhone() {
        return mobilePhone;
    }

    public void setMobilePhone(String mobilePhone) {
        this.mobilePhone = mobilePhone;
    }
    public String getResidencyTypeName() {
        return residencyTypeName;
    }

    public void setResidencyTypeName(String residencyTypeName) {
        this.residencyTypeName = residencyTypeName;
    }
    public String getEducationName() {
        return educationName;
    }

    public void setEducationName(String educationName) {
        this.educationName = educationName;
    }
    public String getTitleName() {
        return titleName;
    }

    public void setTitleName(String titleName) {
        this.titleName = titleName;
    }
    public String getSocialDepartmentCode() {
        return socialDepartmentCode;
    }

    public void setSocialDepartmentCode(String socialDepartmentCode) {
        this.socialDepartmentCode = socialDepartmentCode;
    }
    public String getSocialDepartmentName() {
        return socialDepartmentName;
    }

    public void setSocialDepartmentName(String socialDepartmentName) {
        this.socialDepartmentName = socialDepartmentName;
    }
    public String getWorkYear() {
        return workYear;
    }

    public void setWorkYear(String workYear) {
        this.workYear = workYear;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public String getBankAddress() {
        return bankAddress;
    }

    public void setBankAddress(String bankAddress) {
        this.bankAddress = bankAddress;
    }
    public Long getSyncDay() {
        return syncDay;
    }

    public void setSyncDay(Long syncDay) {
        this.syncDay = syncDay;
    }
    public Integer getHrState() {
        return hrState;
    }

    public void setHrState(Integer hrState) {
        this.hrState = hrState;
    }
    

    public List<RosterJobEntity> getRosterJobList() {
        return rosterJobList;
    }

    public void setRosterJobList(List<RosterJobEntity> rosterJobList) {
        this.rosterJobList = rosterJobList;
    }

    public List<RosterSocialSecurityEntity> getRosterSocialSecurityList() {
        return rosterSocialSecurityList;
    }

    public void setRosterSocialSecurityList(List<RosterSocialSecurityEntity> rosterSocialSecurityList) {
        this.rosterSocialSecurityList = rosterSocialSecurityList;
    }

    public List<RosterAccumulationFundEntity> getRosterAccumulationFundList() {
        return rosterAccumulationFundList;
    }

    public void setRosterAccumulationFundList(List<RosterAccumulationFundEntity> rosterAccumulationFundList) {
        this.rosterAccumulationFundList = rosterAccumulationFundList;
    }

    public List<RosterAttendanceEntity> getRosterAttendanceList() {
        return rosterAttendanceList;
    }

    public void setRosterAttendanceList(List<RosterAttendanceEntity> rosterAttendanceList) {
        this.rosterAttendanceList = rosterAttendanceList;
    }

    public List<RosterTransferEntity> getRosterTransferList() {
        return rosterTransferList;
    }

    public void setRosterTransferList(List<RosterTransferEntity> rosterTransferList) {
        this.rosterTransferList = rosterTransferList;
    }

    public List<RosterCertificateEntity> getRosterCertificateList() {
        return rosterCertificateList;
    }

    public void setRosterCertificateList(List<RosterCertificateEntity> rosterCertificateList) {
        this.rosterCertificateList = rosterCertificateList;
    }
}
